@@ -72,7 +72,7 @@ func TestBoltPersistentState(t *testing.T) {
 			string(bucket): {
 				string(key): string(value),
 			},
-		}, data.(map[string]map[string]string))
+		}, data)
 
 		assert.NoError(t, b1.Close())
 
@@ -138,8 +138,7 @@ func TestBoltPersistentStateGeneric(t *testing.T) {
 		}
 	}()
 	testPersistentState(t, func() PersistentState {
-		tempDir, err := os.MkdirTemp("", "chezmoi-test")
-		assert.NoError(t, err)
+		tempDir := t.TempDir()
 		absPath := NewAbsPath(tempDir).JoinString("chezmoistate.boltdb")
 		b, err := NewBoltPersistentState(system, absPath, BoltPersistentStateReadWrite)
 		assert.NoError(t, err)
