@@ -19,6 +19,7 @@ func (c *Config) newCatCmd() *cobra.Command {
 		Args:              cobra.MinimumNArgs(1),
 		RunE:              c.makeRunEWithSourceState(c.runCatCmd),
 		Annotations: newAnnotations(
+			persistentStateModeReadWrite,
 			requiresSourceDirectory,
 		),
 	}
@@ -27,7 +28,7 @@ func (c *Config) newCatCmd() *cobra.Command {
 }
 
 func (c *Config) runCatCmd(cmd *cobra.Command, args []string, sourceState *chezmoi.SourceState) error {
-	targetRelPaths, err := c.targetRelPaths(sourceState, args, nil)
+	targetRelPaths, err := c.targetRelPaths(sourceState, args, targetRelPathsOptions{})
 	if err != nil {
 		return err
 	}
